Python 3.9.16 (main, Mar 1 2023, 18:30:21) [MSC v.1916 64 bit (AMD64)]

Type "copyright", "credits" or "license" for more information.

IPython -- An enhanced Interactive Python.

In [1]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[1]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [2]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Traceback (most recent call last):

File "C:\Users\yrc2\AppData\Local\Temp\ipykernel_31412\3568793458.py", line 3, in <cell line: 3>

cane.plot_oil_recovery_integration(load=True)

File "C:\Users\yrc2\Code\biosteam\Bioindustrial-Park\biorefineries\cane\contour_plots.py", line 439, in plot_oil_recovery_integration

fig, axes, CSs, CB, other_axes = plot_contour_2d(

File "C:\Users\yrc2\Code\biosteam\biosteam\plots\plots.py", line 973, in plot_contour_2d

assert Z.shape == (*X.shape, nrows, ncols), (

AssertionError: Z was shape (5, 5, 2, 2), but expeted shape (10, 10, 2, 2); Z.shape must be (X, Y, M, N), where (X, Y) is the shape of both X and Y, M is the number of metrics, and N is the number of elements in titles (if given)

In [3]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[3]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [4]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[4]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [5]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[5]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [6]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[6]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [7]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[7]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [8]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[8]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [9]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Traceback (most recent call last):

File "C:\Users\yrc2\AppData\Local\Temp\ipykernel_31412\3568793458.py", line 3, in <cell line: 3>

cane.plot_oil_recovery_integration(load=True)

File "C:\Users\yrc2\Code\biosteam\Bioindustrial-Park\biorefineries\cane\contour_plots.py", line 436, in plot_oil_recovery_integration

MetricBar('MBSP', format_units('USD/L'), plt.cm.get_cmap('viridis_r'), tickmarks(d0[~np.isnan(d0)], 5, 1, expand=0, p=0.5), 20, 1),

File "C:\Users\yrc2\Code\biosteam\biosteam\plots\plots.py", line 119, in rounded_tickmarks_from_data

return rounted_tickmarks_from_range(lb, ub, N_ticks, step_min, lb_max, ub_min, expand, f, center,

File "C:\Users\yrc2\Code\biosteam\biosteam\plots\plots.py", line 131, in rounted_tickmarks_from_range

return rounded_linspace(lb, ub, N_ticks, step_min, f, center, p)

File "C:\Users\yrc2\Code\biosteam\biosteam\plots\plots.py", line 156, in rounded_linspace

return [f(i) for i in values]

File "C:\Users\yrc2\Code\biosteam\biosteam\plots\plots.py", line 156, in <listcomp>

return [f(i) for i in values]

TypeError: 'NoneType' object is not callable

In [10]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[10]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [11]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[11]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [12]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[12]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [13]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[13]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [14]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[14]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [15]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=True)

Out[15]:

(<Figure size 640x480 with 16 Axes>,

[[{'ax': <AxesSubplot: title={'center': 'Mechanical oil recovery'}, ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: title={'center': 'Integrated oil recovery'}>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}],

[{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]', ylabel='Microbial oil yield [wt. %]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >},

{'ax': <AxesSubplot: xlabel='Microbial oil recovery [%]'>,

'twinx': <AxesSubplot: >,

'twiny': <AxesSubplot: >}]])

In [16]: from biorefineries import cane

...: cane.YRCP2023()

...: cane.plot_oil_recovery_integration(load=False)